@@ -30,6 +30,10 @@ class BarCode(SingletonModel):
 
         return [cls.format_code(code) for code in next_codes]
 
+    @classmethod
+    def get_next_code(cls):
+        return cls.get_next_codes(1)[0]
+
     @classmethod
     def format_code(cls, code):
         ean = cls.get_ean("1{:011d}".format(code))
